package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallMeta;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.ManualPointsArtifact;

import de.intevation.flys.artifacts.model.ManualPointsFacet;
import de.intevation.flys.artifacts.model.FacetTypes;

import de.intevation.flys.artifacts.resources.Resources;


/**
 * The only state for an ManualPointArtifact.
 */
public class ManualPointsSingleState
extends      DefaultState
implements   FacetTypes
{
    /** Developer-centric description of facet. */
    public static final String I18N_DESCRIPTION = "facet.longitudinal_section.manualpoint";

    /** The logger that is used in this state. */
    private static final Logger logger = Logger.getLogger(ManualPointsSingleState.class);


    /**
     * Add an ManualPointsFacet to list of Facets.
     *
     * @param artifact Ignored.
     * @param hash Ignored.
     * @param context Ignored.
     * @param meta CallMeta to be used for internationalization.
     * @param facets List to add ManualPointsFacet to.
     *
     * @return null.
     */
    public Object compute(
        FLYSArtifact artifact,
        String       hash,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        logger.debug("ManualPointsSingleState.compute()");
        ManualPointsArtifact points = (ManualPointsArtifact) artifact;

        // Add Facet per Diagram type if data given.
        for (ChartType ct: ChartType.values()) {
            String pointData = points.getDataAsString(ct + "." + MANUALPOINTS + ".data");
            if (pointData != null && !pointData.equals("") && !pointData.equals("[]")) {
                String fName = ct + "." + MANUALPOINTS;
                ManualPointsFacet facet = new ManualPointsFacet(
                    0,
                    fName,
                    Resources.getMsg(meta, "manualpoints", "Manual Points"));
        
                facets.add(facet);
            }
            else {
                //logger.debug("No points for " + ct);
            }
        }

        return null;
    }


    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
     ) {
        return compute(artifact, hash, meta, facets);
    }


    @Override
    public Object computeFeed(
        FLYSArtifact artifact,
        String hash,
        CallContext context,
        List<Facet> facets,
        Object old
    ) {
        return compute(artifact, hash, context.getMeta(), facets);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
